==> jc-1.4.0.tar.gz: gnu/xml/transform/TextNode.h <==
// final class gnu.xml.transform.TextNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 51b561c907bad84a gnu_xml_transform_TextNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_TextNode_H_
#define _JC_gnu_xml_transform_TextNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TextNode$sub_refs	_jc_gnu_xml_transform_TextNode$sub_refs;
typedef struct _jc_gnu_xml_transform_TextNode$sub_nonrefs	_jc_gnu_xml_transform_TextNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TextNode$refs	_jc_gnu_xml_transform_TextNode$refs;
typedef struct _jc_gnu_xml_transform_TextNode$nonrefs	_jc_gnu_xml_transform_TextNode$nonrefs;
typedef struct _jc_gnu_xml_transform_TextNode$object	_jc_gnu_xml_transform_TextNode$object;

typedef const struct _jc_gnu_xml_transform_TextNode$vmethods	_jc_gnu_xml_transform_TextNode$vmethods;
typedef const struct _jc_gnu_xml_transform_TextNode$vtable	_jc_gnu_xml_transform_TextNode$vtable;
typedef const struct _jc_gnu_xml_transform_TextNode$vtype	_jc_gnu_xml_transform_TextNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TextNode$method$_init$d20c41accfed0ef1(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, jboolean);

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_TextNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
extern void _jc_gnu_xml_transform_TextNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TextNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_TextNode$method_info$doApply$85a30cd55d4e7167;

// Virtual methods structure
struct _jc_gnu_xml_transform_TextNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_TextNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_TextNode$vmethods	gnu_xml_transform_TextNode;
};

// Vtype
struct _jc_gnu_xml_transform_TextNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TextNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TextNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TextNode$refs {
    _jc_gnu_xml_transform_TextNode$sub_refs	gnu_xml_transform_TextNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TextNode$sub_nonrefs {
	jboolean	disableOutputEscaping;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TextNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_TextNode$sub_nonrefs	gnu_xml_transform_TextNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_TextNode$object {
	_jc_gnu_xml_transform_TextNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TextNode$vtype	*vtype;
	_jc_gnu_xml_transform_TextNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TextNode$vtype _jc_gnu_xml_transform_TextNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TextNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TextNode$class_object;

#endif	/* _JC_gnu_xml_transform_TextNode_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/TextNode.h <==
// final class gnu.xml.transform.TextNode

// class file dependencies
// @dep_class ef8509869908c7a6 gnu_xml_transform_TemplateNode
// @dep_class 51b561c907bad84a gnu_xml_transform_TextNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_transform_TemplateNode

#include "gnu/xml/transform/TemplateNode.h"

#ifndef _JC_gnu_xml_transform_TextNode_H_
#define _JC_gnu_xml_transform_TextNode_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_namespace_QName$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TextNode$sub_refs	_jc_gnu_xml_transform_TextNode$sub_refs;
typedef struct _jc_gnu_xml_transform_TextNode$sub_nonrefs	_jc_gnu_xml_transform_TextNode$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TextNode$refs	_jc_gnu_xml_transform_TextNode$refs;
typedef struct _jc_gnu_xml_transform_TextNode$nonrefs	_jc_gnu_xml_transform_TextNode$nonrefs;
typedef struct _jc_gnu_xml_transform_TextNode$object	_jc_gnu_xml_transform_TextNode$object;

typedef const struct _jc_gnu_xml_transform_TextNode$vmethods	_jc_gnu_xml_transform_TextNode$vmethods;
typedef const struct _jc_gnu_xml_transform_TextNode$vtable	_jc_gnu_xml_transform_TextNode$vtable;
typedef const struct _jc_gnu_xml_transform_TextNode$vtype	_jc_gnu_xml_transform_TextNode$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TextNode$method$_init$d20c41accfed0ef1(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_TemplateNode$object *_jc_gnu_xml_transform_TextNode$method$clone$b8a038f4254cb648(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_TextNode$method$doApply$85a30cd55d4e7167(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TextNode$method_info$clone$b8a038f4254cb648;
extern _jc_method _jc_gnu_xml_transform_TextNode$method_info$doApply$85a30cd55d4e7167;

// Virtual methods structure
struct _jc_gnu_xml_transform_TextNode$vmethods {
	struct _jc_gnu_xml_transform_TemplateNode$object	*(*clone$b8a038f4254cb648)(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
	void	(*doApply$85a30cd55d4e7167)(_jc_env *, struct _jc_gnu_xml_transform_TextNode$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_object *, jint, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_TextNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplateNode$vmethods	gnu_xml_transform_TemplateNode;
	_jc_gnu_xml_transform_TextNode$vmethods	gnu_xml_transform_TextNode;
};

// Vtype
struct _jc_gnu_xml_transform_TextNode$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TextNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TextNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TextNode$refs {
    _jc_gnu_xml_transform_TextNode$sub_refs	gnu_xml_transform_TextNode;
    _jc_gnu_xml_transform_TemplateNode$sub_refs	gnu_xml_transform_TemplateNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TextNode$sub_nonrefs {
	jboolean	disableOutputEscaping;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TextNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplateNode$sub_nonrefs	gnu_xml_transform_TemplateNode;
    _jc_gnu_xml_transform_TextNode$sub_nonrefs	gnu_xml_transform_TextNode;
};

// Object instance structure
struct _jc_gnu_xml_transform_TextNode$object {
	_jc_gnu_xml_transform_TextNode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TextNode$vtype	*vtype;
	_jc_gnu_xml_transform_TextNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TextNode$vtype _jc_gnu_xml_transform_TextNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TextNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TextNode$class_object;

#endif	/* _JC_gnu_xml_transform_TextNode_H_ */
